SystemOrganization addCategory: #'Versionner-Core-Commands'!

Object subclass: #MBCommand
	instanceVariableNames: 'target targetNode requestor'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBCommand commentStamp: '<historical>' prior: 0!
A MBCommand is a the base class for all commands available in Versionner.
!

MBCommand subclass: #MBAbstractPackageInfoCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

MBAbstractPackageInfoCommand subclass: #MBBrowsePackageCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBBrowsePackageCommand methodsFor: 'documentation' stamp: 'dkh 3/2/2011 14:05'!
documentation
	^ 'Open a system browser on the selected project configuration or package.'! !

!MBBrowsePackageCommand methodsFor: 'execute' stamp: 'dkh 3/2/2011 14:07'!
execute
	target classForBrowsing browse! !

!MBBrowsePackageCommand methodsFor: 'accessing' stamp: 'dkh 3/2/2011 14:05'!
title
	^ 'browse'! !

MBAbstractPackageInfoCommand subclass: #MBLoadPackageCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBLoadPackageCommand methodsFor: 'documentation' stamp: 'dkh 2/28/2011 11:53'!
documentation
	^ 'Perform a project load using the specified package or project as the load list.'! !

!MBLoadPackageCommand methodsFor: 'execute' stamp: 'dkh 3/5/2011 18:09'!
execute
	| answer |
	answer := MBPlatform current confirm: 'Are you sure you want to load using ', target packageName.
	answer ifTrue:  [ | version |
		version := target configurationInfo currentVersion.
		version load: version defaultPackageNamesToLoad, { target packageName } ]! !

!MBLoadPackageCommand methodsFor: 'accessing' stamp: 'dkh 3/20/2011 16:15'!
title
	^ 'load ', target typeLabel! !

MBAbstractPackageInfoCommand subclass: #MBPackageChangesCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBPackageChangesCommand methodsFor: 'private' stamp: 'TesterBob 3/20/2011 13:42'!
changesForSymbolicVersion: symbolicVersion workingCopy: wc
	| repository info ancestorVersion ref gofer resolved version packageSpec packageName ancestorVersionInfo |
	(repository := self selectRepositoryFromWorkingCopy: wc) ifNil: [ ^ self ].
	info := target configurationInfo.
	version := info project version: symbolicVersion.
	packageSpec := version
		packageNamed: wc packageName
		ifAbsent: [ ^ MBPlatform current inform: 'No package to compare ', target name, ' to in version' , symbolicVersion printString ].
	packageName := packageSpec file.
	ref := ((gofer := Gofer new)
		repository: repository;
		version: packageName) references first.
	(resolved := ref resolveAllWith: gofer) isEmpty
		ifTrue: [ 
			ref := ((gofer := Gofer new)
				repository: repository;
				package: packageName) references first.
			resolved := ref resolveAllWith: gofer ].
	ancestorVersionInfo := repository versionInfoFromVersionNamed: resolved last name.
	ancestorVersion := repository versionWithInfo: ancestorVersionInfo.
	self
		findChangesBetween: wc package snapshot
		toLabel: wc ancestry ancestorString , ' (' , info currentVersion versionString , ')'
		and: ancestorVersion snapshot
		fromLabel: ancestorVersion info name , ' (' , symbolicVersion printString , ' )'! !

!MBPackageChangesCommand methodsFor: 'documentation' stamp: 'dkh 3/20/2011 14:01'!
documentation
	^ 'View changes to the package ancestor in the selected repository or the corresponding package version in the selected symbolic version.'! !

!MBPackageChangesCommand methodsFor: 'execute' stamp: 'dkh 3/20/2011 12:50'!
execute
	"View the changes made in the working copy."

	| wc repositoryOrSymbolicVersion |
	wc := target spec workingCopy ifNil: [ ^ self ].
	wc ancestors isEmpty
		ifTrue: [ ^ self ].
	(repositoryOrSymbolicVersion := self selectRepositoryOrSymbolicVersion: wc) ifNil: [ ^ self ].
	repositoryOrSymbolicVersion isSymbol
		ifTrue: [ self changesForSymbolicVersion: repositoryOrSymbolicVersion workingCopy: wc]
		ifFalse: [ self findChangesFor: wc relativeToRepository: repositoryOrSymbolicVersion ]! !

!MBPackageChangesCommand methodsFor: 'utility' stamp: 'dkh 3/20/2011 10:34'!
selectRepositoryOrSymbolicVersion: workingCopy
	| project symbolicVersions repos list values |
	project := target spec project.
	symbolicVersions := project symbolicVersionSymbols select: [ :each | project hasVersion: each ].
	repos := workingCopy repositoryGroup repositories.
	list := (symbolicVersions collect: [:each | each printString]), (repos collect: [ :r | r description ]).
	values := symbolicVersions, repos.
	^MBPlatform current
		chooseFrom: list
		values: values
		lines: {symbolicVersions  size}
		title: 'Please choose which symbolic version or repository'.
! !

!MBPackageChangesCommand methodsFor: 'accessing' stamp: 'dkh 3/20/2011 16:41'!
title
	^ 'changes'! !

MBAbstractPackageInfoCommand subclass: #MBPackageHistoryCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBPackageHistoryCommand methodsFor: 'documentation' stamp: 'dkh 3/20/2011 14:04'!
documentation
	^ 'view package history'! !

!MBPackageHistoryCommand methodsFor: 'execute' stamp: 'DaleHenrichs 03/22/2011 16:58'!
execute

	target workingCopy ancestors isEmpty
		ifTrue: [ ^ self ].
	MBPlatform current browseVersionHistoryFor: target! !

!MBPackageHistoryCommand methodsFor: 'accessing' stamp: 'dkh 3/20/2011 14:03'!
title
	^ 'history'! !

MBAbstractPackageInfoCommand subclass: #MBRevertPackageCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBRevertPackageCommand methodsFor: 'documentation' stamp: 'DaleHenrichs 03/07/2011 15:43'!
documentation
	^ 'Revert the changes that have been made to this package.'! !

!MBRevertPackageCommand methodsFor: 'execute' stamp: 'DaleHenrichs 03/07/2011 15:46'!
execute

	self pickAncestorVersionInfo ifNotNilDo: [:info |
		(target workingCopy repositoryGroup versionWithInfo: info
			ifNone: [^self inform: 'No repository found for ', info name]
		) load].
! !

!MBRevertPackageCommand methodsFor: 'private' stamp: 'DaleHenrichs 03/07/2011 15:46'!
pickAncestorVersionInfo
	| ancestors |
	ancestors := target workingCopy ancestry breadthFirstAncestors.
	^MBPlatform current 
		chooseFrom: (ancestors collect: [:ea | ea name])
		values: ancestors
		title: 'Package:' 
! !

!MBRevertPackageCommand methodsFor: 'accessing' stamp: 'DaleHenrichs 03/07/2011 15:43'!
title
	^ 'revert'! !

MBAbstractPackageInfoCommand subclass: #MBSavePackageCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBSavePackageCommand methodsFor: 'documentation' stamp: 'DaleHenrichs 03/07/2011 15:33'!
documentation
	^ 'Save a new version of the mcz for the given repository in its repository.'! !

!MBSavePackageCommand methodsFor: 'execute' stamp: 'DaleHenrichs 03/07/2011 16:01'!
execute
	| message repo gofer |
	message := MBPlatform current multilineRequest: 'Enter commit message' initialAnswer: ''.
	message == nil
		ifTrue: [ ^ self ].
	repo := self checkUserInRepositoryOfPackage: target spec name.
	gofer := Gofer new.
	gofer disablePackageCache.
			gofer repository: repo.
			gofer package: target spec name.
			gofer commit: message! !

!MBSavePackageCommand methodsFor: 'accessing' stamp: 'DaleHenrichs 03/07/2011 15:33'!
title
	^ 'save'! !

!MBCommand class methodsFor: 'testing' stamp: 'dkh 3/5/2011 17:06'!
isMorphicCommand

	^true! !

!MBCommand class methodsFor: 'testing' stamp: 'dkh 3/5/2011 17:06'!
isOBCommand

	^true! !

!MBCommand class methodsFor: 'util' stamp: 'dkh 3/4/2011 12:30'!
newCommand
	" 
	MBCommand newCommand
	"
	| command baseName newCommandName receiverClassIndex clss title documentation |
	baseName := MBPlatform current request: 'Enter the base name (''MB'' and ''Command'' will be automatically added'.
	baseName ifNil: [ ^ self ].
	
	clss := MBCommand subclasses.
	receiverClassIndex := MBPlatform current chooseFrom: (clss collect: #name).
	receiverClassIndex isZero ifTrue: [ ^ self ].
	
	newCommandName := 'MB', baseName, 'Command'.
	command := 
		(clss at: receiverClassIndex) 
			subclass: newCommandName asSymbol 
			instanceVariableNames: '' 
			classVariableNames: '' 
			poolDictionaries: '' 
			category: self category.
	
	documentation := MBPlatform current request: 'Enter the documentation'.
	documentation ifNil: [ ^ self ].
	 command compile: 'documentation
	^ ''', documentation, '''' classified: 'documentation'.

	 command compile: 'execute
	self subclassResponsibility ' classified: 'execute'.
	
	title := MBPlatform current request: 'Enter the command title'.
	title ifNil: [ ^ self ].
	 command compile: 'title
	^ ''', title, '''' classified: 'accessing'.
	
	clss := MBInfo allSubclasses.
	receiverClassIndex := MBPlatform current chooseFrom: (clss collect: #name).
	receiverClassIndex isZero ifTrue: [ ^ self ].
	(clss at: receiverClassIndex) compile: 'cmd', baseName, '
	^ ', newCommandName classified: 'commands'! !

!MBCommand class methodsFor: 'instance creation' stamp: 'dkh 3/6/2011 16:07'!
target: target for: requestor
	^ self new
		target: target;
		requestor: requestor;
		yourself! !

!MBCommand methodsFor: 'versions' stamp: 'DaleHenrichs 03/07/2011 11:46'!
askForVersionNumber
	"Return a new version number as a string"

	| latestVersion newVersion versions |
	newVersion := (versions := target configurationInfo versions) isEmpty
		ifTrue: [ '1.0' ]
		ifFalse: [ 
			latestVersion := versions first version.
			latestVersion versionNumber copy incrementMinorVersionNumber printString ].
	^ MBPlatform current  request: 'enter new version number' initialAnswer: newVersion! !

!MBCommand methodsFor: 'repositories' stamp: 'dkh 4/7/2011 21:30'!
checkUserInRepository: repository
	"Try to find the http repository of packageName. If it does not find one, then add one and ask for the username and password"

	| answerUser |
	(repository isKindOf: MCHttpRepository ) ifFalse: [ ^self ].
	repository user
		ifEmpty: [ 
			answerUser := MBPlatform current confirm: 'No user defined. Do you want to add one? '.
			answerUser
				ifTrue: [ 
					repository user: self username.
					repository password: self password ] ]! !

!MBCommand methodsFor: 'repositories' stamp: 'DaleHenrichs 03/07/2011 15:59'!
checkUserInRepositoryOfPackage: packageName
	"Try to find the http repository of packageName. If it does not find one, then add one and ask for the username and password"

	| repo |
	(repo := self repositoryOfPackageNamed: packageName) ifNil: [ ^nil ].
	self checkUserInRepository: repo.
	^repo! !

!MBCommand methodsFor: 'utility' stamp: 'dkh 3/5/2011 20:33'!
chooseRepositoryFromList: repos
	"Return the repository of the configuration. Create one (using UI) if necessary"

	repos size > 1
		ifTrue: [ 
			^ MBPlatform current
				chooseFrom: (repos collect: [ :repo | repo description ])
				values: repos
				title: 'Select repository' ].
	^ repos first! !

!MBCommand methodsFor: 'accessing-computed' stamp: 'dkh 4/7/2011 00:26'!
configurationClass
	^ target configurationInfo configurationClass! !

!MBCommand methodsFor: 'repositories' stamp: 'dkh 4/17/2011 13:11'!
configurationReferencesFrom: aRepository

	| map |
	map := Dictionary new.
	aRepository goferReferences do: [ :ref | 
		(ref packageName beginsWith: 'ConfigurationOf')
			ifTrue: [ | nameWithBranch |
				nameWithBranch := ref metacelloPackageNameWithBranch at: 2.
				(map at: nameWithBranch ifAbsent: [map at: nameWithBranch put: OrderedCollection new]) add: ref ]].
	^map! !

!MBCommand methodsFor: 'documentation' stamp: 'fds 2/26/2011 10:48'!
documentation
	self subclassResponsibility! !

!MBCommand methodsFor: 'execute' stamp: 'fds 2/26/2011 19:45'!
execute
	self subclassResponsibility ! !

!MBCommand methodsFor: 'execute' stamp: 'dkh 4/6/2011 10:27'!
executeInTransaction
	"since gemstone is transactional, there needs to be a facility for ensure that the commands get executed within a transaction"
	
	^MBPlatform current inTransactionDo: [ self execute ]! !

!MBCommand methodsFor: 'changes' stamp: 'dkh 3/20/2011 12:52'!
findChangesBetween: packageSnapshot toLabel: toLabel and: ancestorVersioSnapshot fromLabel: fromLabel

	MBPlatform current
		findChangesBetween: packageSnapshot
		toLabel: toLabel
		and: ancestorVersioSnapshot
		fromLabel: fromLabel! !

!MBCommand methodsFor: 'changes' stamp: 'dkh 3/20/2011 12:49'!
findChangesFor: wc relativeToRepository: repositoryOrSymbolicVersion 

	^MBPlatform current findChangesFor: wc relativeToRepository: repositoryOrSymbolicVersion ! !

!MBCommand methodsFor: 'documentation' stamp: 'dkh 4/10/2011 19:14'!
helpDocumentation
	^self documentation! !

!MBCommand methodsFor: 'initialize-release' stamp: 'fds 2/26/2011 10:49'!
initialize
	super initialize.
	
	"Calling #documentation is there just to enforce one to provide a documentation"   
	self documentation! !

!MBCommand methodsFor: 'utility' stamp: 'dkh 3/4/2011 05:21'!
on: anObject for: aRequestor
	^ self class on: anObject for: aRequestor! !

!MBCommand methodsFor: 'ordering' stamp: 'fds 2/26/2011 10:46'!
order
	^ self title! !

!MBCommand methodsFor: 'repositories' stamp: 'DaleHenrichs 03/09/2011 11:38'!
password
	| password |
	password := target configurationRoot password. 
	password ifNotNil: [ ^ password ].
	password := MBPlatform current requestPassword: 'enter your Monticello password for '.
	target configurationRoot password: password.
	^ password! !

!MBCommand methodsFor: 'repositories' stamp: 'dkh 3/5/2011 16:02'!
pickRepository
	^ self pickRepositoryFrom: self repositories.
! !

!MBCommand methodsFor: 'repositories' stamp: 'dkh 4/7/2011 15:38'!
pickRepositoryFrom: repositories

	^self pickRepositoryFrom: repositories message: 'Choose repository'! !

!MBCommand methodsFor: 'repositories' stamp: 'dkh 4/7/2011 20:39'!
pickRepositoryFrom: repositories message: message
	| index |
	index := MBPlatform current chooseFrom: (repositories collect: [ :ea | ea description ]) message: message.
	index ifNil: [ ^nil ].
	^ index = 0
		ifFalse: [ repositories at: index ]! !

!MBCommand methodsFor: 'accessing-computed' stamp: 'AlexandreBergel 4/15/2011 10:19'!
projectName
	^ MBToolBox baseNameOf: self configurationClass name! !

!MBCommand methodsFor: 'repositories' stamp: 'dkh 3/5/2011 15:57'!
repositories
	^MCRepositoryGroup default repositories! !

!MBCommand methodsFor: 'repositories' stamp: 'dkh 4/7/2011 21:29'!
repositoryOfPackageNamed: packageName
	"Return the repository of the configuration. Create one (using UI) if necessary"

	| mcPackage workingCopy repositories repository repositoryIndex username password |
	mcPackage := MCPackage named: packageName.
	workingCopy := mcPackage workingCopy.
	repositories := workingCopy repositoryGroup repositories reject: [ :rep | rep == MCCacheRepository default ].
	repositories
		ifEmpty: [ 
			| projectName answer squeakSourceURL |
			projectName := MBToolBox baseNameOf: self configurationClass name asString.
			squeakSourceURL := 'http://www.squeaksource.com/' , projectName.
			answer := MBPlatform current
				confirm: 'No repository associated with your project. Do you want to add ' , squeakSourceURL.
			answer
				ifFalse: [ 
					MBPlatform current inform: 'Add a http repository with Monticello browser'.
					^ nil ].
			repository := MCHttpRepository location: squeakSourceURL user: '' password: ''.
			repository user isEmpty
				ifTrue: [ username := self username ].
			repository password isEmpty
				ifTrue: [ password := self password ].
			workingCopy repositoryGroup
				addRepository: (repository := MCHttpRepository location: squeakSourceURL user: username password: password) ].
	repositories size > 1
		ifTrue: [ 
			repositoryIndex := MBPlatform current chooseFrom: (repositories collect: #printString).
			repositoryIndex = 0
				ifTrue: [ ^ nil ].
			repository := repositories at: repositoryIndex ].
	repositories size = 1
		ifTrue: [ repository := repositories first ].
	^ repository! !

!MBCommand methodsFor: 'accessing' stamp: 'dkh 3/6/2011 16:08'!
requestor: aRequestor

	requestor := aRequestor ! !

!MBCommand methodsFor: 'utility' stamp: 'dkh 03/12/2011 01:34'!
selectRepositoryFromWorkingCopy: workingCopy
	| repos repo |
	repos := workingCopy repositoryGroup repositories.
	repos size = 0
		ifTrue: [ ^ MBPlatform current  inform: 'No repositories associated with ' , target name printString ].
	repo := repos size = 1
		ifTrue: [ repos first ]
		ifFalse: [ 
			MBPlatform current
				chooseFrom: (repos collect: [ :r | r description ])
				values: repos
				title: 'Please choose which repository to use for diff' ].
	^ repo! !

!MBCommand methodsFor: 'accessing' stamp: 'fds 2/26/2011 20:01'!
target
	^ target! !

!MBCommand methodsFor: 'accessing' stamp: 'fds 2/26/2011 20:01'!
target: anObject
	target := anObject! !

!MBCommand methodsFor: 'accessing' stamp: 'dkh 3/4/2011 06:16'!
targetNode
	^ targetNode! !

!MBCommand methodsFor: 'accessing' stamp: 'dkh 3/4/2011 06:16'!
targetNode: anObject
	targetNode := anObject! !

!MBCommand methodsFor: 'accessing' stamp: 'JuanPabloSandovalAlcocer 6/30/2012 17:50'!
title
	^ 'Load Cache (beta)'! !

!MBCommand methodsFor: 'repositories' stamp: 'DaleHenrichs 03/09/2011 11:38'!
username
	| username |
	username := target configurationRoot username. 
	username ifNotNil: [ ^ username ].
	username := MBPlatform current request: 'enter your Monticello username (login)'.
	target configurationRoot username: username.
	^ username! !

MBCommand subclass: #MBConfigurationInfoCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

MBConfigurationInfoCommand subclass: #MBBrowseConfigurationCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBBrowseConfigurationCommand methodsFor: 'documentation' stamp: 'fds 2/27/2011 10:41'!
documentation
	^ 'Open a system browser on the selected configuration.'! !

!MBBrowseConfigurationCommand methodsFor: 'execute' stamp: 'dkh 4/7/2011 00:29'!
execute
	self configurationClass browse! !

!MBBrowseConfigurationCommand methodsFor: 'accessing' stamp: 'AlexandreBergel 4/15/2011 09:26'!
title
	^ 'browse configuration'! !

MBConfigurationInfoCommand subclass: #MBConfigurationChangesCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBConfigurationChangesCommand methodsFor: 'documentation' stamp: 'dkh 3/20/2011 14:02'!
documentation
	^ 'View changes for selected configuration against version in selected repository.'! !

!MBConfigurationChangesCommand methodsFor: 'execute' stamp: 'dkh 3/20/2011 12:50'!
execute
	"View the changes made in the working copy."
	
	| wc repo |
	wc := target workingCopy.
	(repo := self selectRepositoryFromWorkingCopy: wc) ifNil: [ ^self ].
	self findChangesFor: wc relativeToRepository: repo! !

!MBConfigurationChangesCommand methodsFor: 'accessing' stamp: 'dkh 3/20/2011 16:13'!
title
	^ 'changes'! !

MBConfigurationInfoCommand subclass: #MBConfigurationPackageHistoryCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBConfigurationPackageHistoryCommand methodsFor: 'documentation' stamp: 'dkh 3/20/2011 14:17'!
documentation
	^ 'view package history'! !

!MBConfigurationPackageHistoryCommand methodsFor: 'execute' stamp: 'DaleHenrichs 03/22/2011 13:04'!
execute

	target workingCopy ancestors isEmpty
		ifTrue: [ ^ self ].
	MBPlatform current browseVersionHistoryFor: target! !

!MBConfigurationPackageHistoryCommand methodsFor: 'accessing' stamp: 'dkh 3/20/2011 14:16'!
title
	^ 'history'! !

MBConfigurationInfoCommand subclass: #MBInspectConfigurationCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBInspectConfigurationCommand methodsFor: 'documentation' stamp: 'fds 2/27/2011 10:47'!
documentation
	^ 'Open a Smalltalk inspector on the Configuration.'! !

!MBInspectConfigurationCommand methodsFor: 'execute' stamp: 'fds 2/27/2011 10:47'!
execute
	target inspect! !

!MBInspectConfigurationCommand methodsFor: 'accessing' stamp: 'fds 2/27/2011 10:47'!
title
	^ 'inspect'! !

MBConfigurationInfoCommand subclass: #MBLoadProjectFromArchiveCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBLoadProjectFromArchiveCommand methodsFor: 'documentation' stamp: 'dkh 4/7/2011 19:54'!
documentation 
	^ 'Load project from an archive.'! !

!MBLoadProjectFromArchiveCommand methodsFor: 'execute' stamp: 'dkh 4/8/2011 11:07'!
execute
	| archiveRepository configRef configurationInfo versionInfos versionInfo version configRefMap configNames configName |
	archiveRepository := self pickRepositoryFrom: self repositories message: 'Choose the archive repository'.
	archiveRepository ifNil: [ ^ self ].
	configRefMap := self configurationReferencesFrom: archiveRepository.
	configRefMap isEmpty
		ifTrue: [ ^ self inform: 'No configurations found in the archive repository ' , archiveRepository description printString ].
	configNames := configRefMap keys.
	configName := MBPlatform current
		chooseFrom: (configNames collect: [ :name | MBToolBox baseNameOf: name ])
		values: configNames
		title: 'Select the desired project'.
	configName ifNil: [ ^ self ].
	configRef := (configRefMap at: configName) asSortedCollection asArray last.
	(Gofer new)
		repository: archiveRepository;
		version: configRef name;
		load.
	configurationInfo := (MBConfigurationInfo configurationClass: (Smalltalk at: configRef packageName asSymbol))
		configurationRoot: MBConfigurationRoot new;
		trimVersionLists: false;
		currentVersion: #notLoaded;
		yourself.
	versionInfos := configurationInfo versions.
	versionInfo := MBPlatform current
		chooseFrom: (versionInfos collect: [ :vrsn | vrsn printString ])
		values: versionInfos
		title: 'Select the desired version'.
	versionInfo ifNil: [ ^ self ].
	version := versionInfo version.
	version repositoryOverrides: {archiveRepository}.
	version load: version defaultPackageNamesToLoad! !

!MBLoadProjectFromArchiveCommand methodsFor: 'ordering' stamp: 'dkh 4/7/2011 22:23'!
order

	^'01'! !

!MBLoadProjectFromArchiveCommand methodsFor: 'accessing' stamp: 'dkh 4/7/2011 19:55'!
title
	^ 'load archive version'! !

MBConfigurationInfoCommand subclass: #MBSaveConfigurationCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBSaveConfigurationCommand methodsFor: 'documentation' stamp: 'dkh 3/20/2011 16:14'!
documentation
	^ 'Save the configuration in its repository. Note that the dependents projects and defined packages are not saved. Use ''checkpoint dev'' command to save packages.'! !

!MBSaveConfigurationCommand methodsFor: 'execute' stamp: 'AlexandreBergel 4/15/2011 10:24'!
execute
	| message |
	message := MBPlatform current multilineRequest: 'Enter commit message' initialAnswer: ''.
	message == nil
		ifTrue: [ ^ self ].
	self executeWithMessage: message! !

!MBSaveConfigurationCommand methodsFor: 'execute' stamp: 'NorbertHartl 4/9/2013 10:40'!
executeWithMessage: message
	"execute with message"
	self checkUserInRepositoryOfPackage: self configurationClass name asString.
	MetacelloToolBox 
		saveConfigurationPackageFor: (MBToolBox baseNameOf: self configurationClass name asString) 
		description: message! !

!MBSaveConfigurationCommand methodsFor: 'accessing' stamp: 'AlexandreBergel 4/15/2011 09:26'!
title
	^ 'save configuration'! !

MBConfigurationInfoCommand subclass: #MBSetUserCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBSetUserCommand methodsFor: 'as yet unclassified' stamp: 'AlexandreBergel 3/28/2011 09:27'!
documentation
	^ 'Set the user and password used when saving and loading packages and configurations.'! !

!MBSetUserCommand methodsFor: 'as yet unclassified' stamp: 'dkh 4/5/2011 21:22'!
execute
	target configurationRoot username: nil.
	target configurationRoot password: nil.
	self username.
	self password.! !

!MBSetUserCommand methodsFor: 'as yet unclassified' stamp: 'AlexandreBergel 3/28/2011 09:27'!
title
	^ 'set user and password'! !

MBConfigurationInfoCommand subclass: #MBToggleTrimVersionListsCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBToggleTrimVersionListsCommand methodsFor: 'documentation' stamp: 'dkh 3/1/2011 21:19'!
documentation
	^ 'Toggle the trim version list flag. Set to true, show up to 5 of the latest versions plus the #development, #bleedingEdge, #stable, current version, and versions with validationIssues. Set to false, show them all'! !

!MBToggleTrimVersionListsCommand methodsFor: 'execute' stamp: 'dkh 03/12/2011 02:25'!
execute
	
	target trimVersionLists: target trimVersionLists not.
	target recalculate. "no external event so force update"
! !

!MBToggleTrimVersionListsCommand methodsFor: 'accessing' stamp: 'JuanPabloSandovalAlcocer 6/30/2012 17:49'!
title
	""
	^ target ifNil: ['toggle trim list [...]'.] ifNotNil: ['toggle trim list [', target trimVersionLists printString, ']'.].! !

MBConfigurationInfoCommand subclass: #MBUnloadConfigurationCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBUnloadConfigurationCommand methodsFor: 'documentation' stamp: 'dkh 2/27/2011 23:22'!
documentation
	^ 'Unload the package for the selected configuration.' ! !

!MBUnloadConfigurationCommand methodsFor: 'execute' stamp: 'dkh 3/4/2011 14:03'!
execute
	| answer |
	answer := MBPlatform current confirm: 'Are you sure you want to unload ' , target name.
	answer
		ifTrue: [ target workingCopy unload ]! !

!MBUnloadConfigurationCommand methodsFor: 'accessing' stamp: 'dkh 2/27/2011 23:26'!
title
	^ 'unload'! !

MBConfigurationInfoCommand subclass: #MBUpdateFromItsRepositoryCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBUpdateFromItsRepositoryCommand methodsFor: 'documentation' stamp: 'fds 2/27/2011 10:48'!
documentation
	^ 'update the configuration from the version contained in its repository'! !

!MBUpdateFromItsRepositoryCommand methodsFor: 'execute' stamp: 'dkh 3/2/2011 16:50'!
execute
	"use the Metacello api"

	target project updateProject.
	! !

!MBUpdateFromItsRepositoryCommand methodsFor: 'accessing' stamp: 'fds 2/27/2011 10:48'!
title
	^ 'update from its repository'! !

MBConfigurationInfoCommand subclass: #MBValidateAllConfigurationCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBValidateAllConfigurationCommand methodsFor: 'documentation' stamp: 'dkh 2/28/2011 20:48'!
documentation
	^ 'Validate all configuration.'! !

!MBValidateAllConfigurationCommand methodsFor: 'execute' stamp: 'dkh 3/6/2011 15:53'!
execute
	MBPlatform current
		showExecuteWhile: [ target configurationRoot configurations doWithIndex: [ :info :index | info validateFull ] ]! !

!MBValidateAllConfigurationCommand methodsFor: 'accessing' stamp: 'dkh 3/2/2011 08:38'!
title
	^ 'validate all configurations'! !

MBConfigurationInfoCommand subclass: #MBValidateConfigurationCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBValidateConfigurationCommand methodsFor: 'documentation' stamp: 'fds 2/27/2011 10:49'!
documentation
	^ 'Validate the selected configuration. The list of errors found is provided.'! !

!MBValidateConfigurationCommand methodsFor: 'execute' stamp: 'dkh 3/6/2011 15:48'!
execute

	| result |
	result := self validate.
	result ifEmpty: [ MBPlatform current inform: 'The configuration is correctly defined'. ^ self ].

	MBPlatform current  inform: 'Issues were found'.
	result explore.
	
! !

!MBValidateConfigurationCommand methodsFor: 'accessing' stamp: 'fds 2/27/2011 10:49'!
title
	^ 'validate'! !

!MBValidateConfigurationCommand methodsFor: 'execute' stamp: 'dkh 3/5/2011 08:31'!
validate
	MBPlatform current showExecuteWhile: [ ^ target validateFull ]! !

MBCommand subclass: #MBDevCycleCommands
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

MBDevCycleCommands subclass: #MBAddConfigurationCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBAddConfigurationCommand methodsFor: 'execute' stamp: 'AlexandreBergel 3/30/2011 16:15'!
askForClassName
	^ MBPlatform current
		request: 'Name of the new Metacello configuration (e.g., ConfigurationOfYourSoftware)' translated
		initialAnswer: 'ConfigurationOf'! !

!MBAddConfigurationCommand methodsFor: 'private' stamp: 'dkh 4/11/2011 15:28'!
collectPackages: addedPackages andProjects: addedConfigurations pattern: patternString repository: repository
	| packagePattern package |
	packagePattern := MBPlatform current
		request: 'Please enter a pattern to filter package names that will be candidates to add to configuration'
		initialAnswer: patternString.
	packagePattern ifNil: [ ^ self ].
	[ 
	| packageNames workingCopies |
	packageNames := OrderedCollection new.
	workingCopies := OrderedCollection new.
	self workingCopies
		do: [ :pkg | 
			((packagePattern match: pkg package name) and: [ (addedPackages includes: pkg package name) not ])
				ifTrue: [ 
					packageNames add: pkg package name.
					workingCopies add: pkg ] ].
	package := MBPlatform current
		chooseFrom: packageNames
		values: workingCopies
		title: 'Add dependent package (cancel to stop)'.
	package
		ifNotNil: [ 
			(package package name beginsWith: 'ConfigurationOf')
				ifTrue: [ addedConfigurations add: package package name ]
				ifFalse: [ addedPackages add: package package name ].
			package ancestry ancestors isEmpty
				ifTrue: [ 
					(MBPlatform current
						confirm:
							'The package: ' , package package name printString , ' has not been committed yet. Would you like to commit it into the '
								, repository description printString, ' repository?')
						ifTrue: [ 
							package repositoryGroup repositories size <= 1
								ifTrue: [ package repositoryGroup addRepository: repository ].
							package currentVersionInfo ] ] ].
	package notNil ] whileTrue.
	(addedPackages isEmpty and: [ addedConfigurations isEmpty ])
		ifTrue: [ MBPlatform current inform: 'No package or configuration added. No baseline has been created' ]! !

!MBAddConfigurationCommand methodsFor: 'documentation' stamp: 'dkh 3/4/2011 16:25'!
documentation
	^ 'Create a new configuration. Prompt for packages and dependent projects. Create a baseline version and an initial development version'! !

!MBAddConfigurationCommand methodsFor: 'execute' stamp: 'JuanPabloSandovalAlcocer 7/26/2012 11:24'!
execute
	| configurationClassName versionNumber addedPackages addedConfigurations repository projectName mcPackage workingCopy configInfo|
	configurationClassName := self askForClassName.
	configurationClassName ifNil: [ ^ self ].
	Smalltalk globals
		at: configurationClassName asSymbol
		ifPresent: [ :ex | ^ self error: 'Class ' , configurationClassName printString , ' already exist' ].
	projectName := MBToolBox baseNameOf: configurationClassName.
	(repository := self repositoryFor: projectName) ifNil: [ ^ self ].

	versionNumber := MBPlatform current request: 'Enter initial version number' 
										     initialAnswer: '1.0'.
	versionNumber ifNil: [ ^ self ].
	addedPackages := OrderedCollection new.
	addedConfigurations := OrderedCollection new.
	
	self collectPackages: addedPackages
		 andProjects: addedConfigurations 
		 pattern: projectName , '*' 
		 repository: repository.
	self
		executeAddBaselineForConfigurationNamed: configurationClassName
		repositoryDescription: repository description
		versionString: versionNumber
		packages: addedPackages
		configurations: addedConfigurations.
	
	mcPackage := MCPackage named: configurationClassName.
	workingCopy := mcPackage workingCopy.
	workingCopy repositoryGroup addRepository: repository.
	"after all save configuration"
	configInfo := (MBConfigurationInfo 
						configurationClass: (Smalltalk at: (configurationClassName asSymbol)))
						configurationRoot: (MBConfigurationRoot current);
						yourself.
	"fixing"
	(MBSaveConfigurationCommand 
				target: configInfo 
				for: requestor) executeWithMessage: 'Creating ConfigurationOf', projectName.
	! !

!MBAddConfigurationCommand methodsFor: 'execute' stamp: 'JuanPabloSandovalAlcocer 7/11/2012 13:01'!
executeAddBaselineForConfigurationNamed: aConfigurationClassName repositoryDescription: repositoryDescription versionString: versionString packages: packageNames configurations: configurationNames
	| baselineVersionString |
	baselineVersionString := versionString , '-baseline'.
	MetacelloToolBox
		createBaseline: baselineVersionString
			for: aConfigurationClassName
			repository: repositoryDescription
			requiredProjects: configurationNames
			packages: packageNames
			dependencies: {}
			groups: {('default' -> packageNames)};
		createDevelopment: versionString
			for: aConfigurationClassName
			importFromBaseline: baselineVersionString
			description: ''! !

!MBAddConfigurationCommand methodsFor: 'ordering' stamp: 'dkh 4/7/2011 22:20'!
order

	^'20'! !

!MBAddConfigurationCommand methodsFor: 'private' stamp: 'dkh 3/7/2011 11:25'!
repositoryFor: projectName
	| repositories repository |
	repositories := self repositories
		select: [ :repo | (repo description beginsWith: 'http:') and: [ repo description endsWith: projectName ] ].
	repository := nil.
	(repositories anySatisfy: [ :http | http description = ('http://www.squeaksource.com/' , projectName) ])
		ifFalse: [ 
			(MBPlatform current confirm: 'Would you like to use http://www.squeaksource.com/' , projectName , ', for your project?')
				ifTrue: [ ^ MCHttpRepository location: 'http://www.squeaksource.com/' , projectName user: '' password: '' ] ].
	repository isNil
		ifTrue: [ 
			repository := repositories isEmpty
				ifTrue: [ self chooseRepositoryFromList: self repositories ]
				ifFalse: [ self chooseRepositoryFromList: repositories , self repositories ] ].
	^ repository! !

!MBAddConfigurationCommand methodsFor: 'accessing' stamp: 'dkh 4/7/2011 21:52'!
title
	^ 'add configuration'! !

!MBAddConfigurationCommand methodsFor: 'private' stamp: 'dkh 3/4/2011 16:21'!
workingCopies
	^ MCWorkingCopy allManagers asSortedCollection: [ :a :b | a name <= b name]! !

MBDevCycleCommands subclass: #MBAddDevelopmentVersionCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBAddDevelopmentVersionCommand methodsFor: 'documentation' stamp: 'dkh 4/7/2011 21:51'!
documentation
	^ 'Create a new development version.'! !

!MBAddDevelopmentVersionCommand methodsFor: 'execute' stamp: 'AlexandreBergel 5/18/2011 18:28'!
execute
	| versionString baselineLines |
	versionString := self askForVersionNumber.
	versionString ifNil: [ ^ self ].

	"get all the baselines"
	baselineLines := target configurationInfo baselines.
	
	"exclude non numerical baselines"
	baselineLines := baselineLines select: [ :v | ($0 to: $9) includes: v printString first  ].

	MetacelloToolBox
		createDevelopment: versionString 
		for:  (MBToolBox baseNameOfConfiguration: self configurationClass) 
		importFromBaseline: baselineLines first  version versionNumber asString
		description: ''

"	MetacelloToolBox
		createVersion: versionString
		for: (MBToolBox baseNameOfConfiguration: self configurationClass)
		from: target version versionString
		description: ''"! !

!MBAddDevelopmentVersionCommand methodsFor: 'ordering' stamp: 'dkh 4/7/2011 22:20'!
order

	^'30'! !

!MBAddDevelopmentVersionCommand methodsFor: 'accessing' stamp: 'dkh 4/7/2011 21:58'!
title
	^ 'add dev'! !

MBDevCycleCommands subclass: #MBAddRepositoryCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBAddRepositoryCommand methodsFor: 'documentation' stamp: 'dkh 4/8/2011 11:44'!
documentation
	^ 'Add a Monticello repository to the default repository group.'! !

!MBAddRepositoryCommand methodsFor: 'execute' stamp: 'dkh 4/8/2011 16:01'!
execute

	MBPlatform current newRepository ifNotNil:
		[:repos | MCRepositoryGroup default addRepository: repos ].


	! !

!MBAddRepositoryCommand methodsFor: 'accessing' stamp: 'dkh 4/8/2011 11:45'!
title
	^ 'add repository'! !

MBDevCycleCommands subclass: #MBBranchConfigurationCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBBranchConfigurationCommand methodsFor: 'documentation' stamp: 'dkh 4/7/2011 22:22'!
documentation
	^ 'Create a branch version for the configuration'! !

!MBBranchConfigurationCommand methodsFor: 'execute' stamp: 'dkh 4/17/2011 13:32'!
execute

	| branchName |
	branchName := MBPlatform current request: 'Enter the new branch name for the ', self projectName printString, ' project.' initialAnswer: 'branch'.
	self checkUserInRepositoryOfPackage: self configurationClass name asString.
	MetacelloToolBox createBranch: branchName for: self configurationClass name asString description: 'Create branch: ', branchName printString! !

!MBBranchConfigurationCommand methodsFor: 'ordering' stamp: 'dkh 4/7/2011 22:23'!
order

	^'00'! !

!MBBranchConfigurationCommand methodsFor: 'accessing' stamp: 'dkh 4/17/2011 13:26'!
title
	^ 'create branch'! !

MBDevCycleCommands subclass: #MBCheckpointDevCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBCheckpointDevCommand methodsFor: 'documentation' stamp: 'dkh 3/5/2011 13:45'!
documentation
	^ 'Save modified packages in their respective repository, update the configuration and save a version of the configuration in it''s repository.'! !

!MBCheckpointDevCommand methodsFor: 'execute' stamp: 'AlexandreBergel 4/15/2011 10:21'!
execute
	| message configClass |
	configClass := self configurationClass.
	message := MBPlatform current
		multilineRequest:
			'Enter commit message for ' , (MBToolBox baseNameOf: configClass name asString) , ' '
				, (target project version: #development) versionString
		initialAnswer: (target project version: #development) versionString, ' ():'.
	message == nil
		ifTrue: [ ^ self ].
	self executeWithMessage: message
! !

!MBCheckpointDevCommand methodsFor: 'execute' stamp: 'AlexandreBergel 4/15/2011 10:22'!
executeWithMessage: message
	| configClass |
	configClass := self configurationClass.
	self checkUserInRepositoryOfPackage: configClass name asString.
	MetacelloToolBox saveModifiedPackagesAndConfigurationIn: configClass description: message.
! !

!MBCheckpointDevCommand methodsFor: 'ordering' stamp: 'dkh 4/7/2011 22:20'!
order

	^'50'! !

!MBCheckpointDevCommand methodsFor: 'accessing' stamp: 'dkh 3/5/2011 13:44'!
title
	^ 'checkpoint dev'! !

MBDevCycleCommands subclass: #MBHelpCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBHelpCommand methodsFor: 'documentation' stamp: 'dkh 4/6/2011 15:10'!
documentation
	^ 'Open the help window'! !

!MBHelpCommand methodsFor: 'execute' stamp: 'dkh 4/10/2011 21:20'!
execute
	Smalltalk at: #HelpBrowser ifPresent: [ :class | ^class openOn: (Smalltalk at: #VersionnerHelp) ].
	self workspaceHelp! !

!MBHelpCommand methodsFor: 'ordering' stamp: 'dkh 4/7/2011 22:20'!
order

	^'80'! !

!MBHelpCommand methodsFor: 'accessing' stamp: 'dkh 4/6/2011 15:11'!
title
	^ 'help'! !

!MBHelpCommand methodsFor: 'execute' stamp: 'dkh 4/10/2011 20:41'!
workspaceHelp
	| helpText |
	helpText := '"Versionner is a graphical tool to manage the dependencies and the version of your software. It is a complete replacement of the Monticello browser and acts as a facade for Metacello. You can use Versionner in a number of different scenarios.
	
**1-Creating a new configuration**
Press the button ''+Configuration'' and enter the name of your configuration. An initial baseline will also be produced. Your configuration and the new baseline will be listed on the left hand side of the browser. 

**2-Load a configuration**
The first button of the browser is for loading a configuration from its corresponding SqueakSource project. For example, entering ''Pharo'' will try to load ''ConfigurationOfPharo'' from the ''Pharo'' squeaksource project.

**3-Add a new baseline**
A baseline defines the dependencies of your software, including the list of dependent configurations, and the list of packages that defines your applications. Selecting ''Add Baseline'' by right clicking on an existing baseline will first ask you about your squeaksource username and password will be requested.  You then need to enter the version of your baseline (e.g., 0.1).
The final step is to add the dependent packages. 

**4-Add a new version**
A version defines the version of each packages used by your last baseline. At each change in your source code, you need to create a new version. Pressing ''save all and add development version'' by right clicking in a baseline or version may be the option you want to use. Versionner will try to guess what is the following number you need to use. 
Each unsaved dependent package is then saved. You need to enter a comment for the individual saved package. The configuration itself is then saved. At that stage, all your code is stored in squeaksource.

**5-Reviewing recent changes**
It may be useful to review your change, for example when you want to enter a comment when creating a version. At the bottom of the right hand side panel, you have the list of dependent packages. Modified packages will be designed with a ''*''. Right click on a package to see the difference with the last version stored in the squeaksource project. You can compare a package from the stable version of the software, or from the last commit made on squeaksource.

**6-Load a baseline or a version**
Simply right click on it and press ''load''

**7-Updating a configuration**
In case of concurrent development, you may have to update your configuration. Right-click on the configuration, and press the corresponding menu entry.

**8-Contact**
Feedback are welcome. Send them to the pharo mailing list, or directly to the author alexandrebergel@me.com
"
'.
	MBPlatform current edit: helpText label: 'Versionner Help'! !

MBDevCycleCommands subclass: #MBLoadConfigurationCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBLoadConfigurationCommand methodsFor: 'execute' stamp: 'AlexandreBergel 12/1/2011 14:07'!
askForProjectName
	^ self pickRepositoryFrom: self repositories message: 'Choose the repository where project is located'! !

!MBLoadConfigurationCommand methodsFor: 'documentation' stamp: 'dkh 3/5/2011 15:27'!
documentation
	^ 'Load configuration from a repository'! !

!MBLoadConfigurationCommand methodsFor: 'execute' stamp: 'AlexandreBergel 12/1/2011 14:08'!
execute
	| projectRepository configRef configurationInfo versionInfos versionInfo version configRefMap configNames configName |
	projectRepository := self askForProjectName.
	projectRepository ifNil: [ ^ self ].
	configRefMap := self configurationReferencesFrom: projectRepository.
	
	configRefMap isEmpty
		ifTrue: [ ^ self inform: 'No configurations found in the project repository ' , projectRepository description printString ].
	configNames := configRefMap keys asSortedCollection asArray.
	configName := MBPlatform current
		chooseFrom: (configNames collect: [ :name | MBToolBox baseNameOf: name ])
		values: configNames
		title: 'Select the desired project'.
	configName ifNil: [ ^ self ].
	
	configRef := (configRefMap at: configName) asSortedCollection asArray last.
	Gofer new
		repository: projectRepository;
		version: configRef name;
		load! !

!MBLoadConfigurationCommand methodsFor: 'ordering' stamp: 'dkh 4/7/2011 22:20'!
order

	^'10'! !

!MBLoadConfigurationCommand methodsFor: 'accessing' stamp: 'dkh 3/5/2011 15:26'!
title
	^ 'load configuration'! !

MBDevCycleCommands subclass: #MBLoadProjectCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBLoadProjectCommand methodsFor: 'accessing' stamp: 'AlexandreBergel 8/10/2011 17:05'!
configurationNameForProject: aSqueaksourceProjectName
	^ 'ConfigurationOf', (self normalizeProjectName: aSqueaksourceProjectName)! !

!MBLoadProjectCommand methodsFor: 'documentation' stamp: 'AlexandreBergel 5/18/2011 19:04'!
documentation
	^ 'Load project'! !

!MBLoadProjectCommand methodsFor: 'execute' stamp: 'AlexandreBergel 12/1/2011 14:20'!
execute
	| projectName loadLastVersion configurationName index url |
	
	index := UIManager default chooseFrom: #('squeaksource' 'ss3.gemstone.com') title: 'Say where you want to load from'.
	index = 0 ifTrue: [ ^ self ].
	index = 1 ifTrue: [ url := 'http://www.squeaksource.com/' ].
	index = 2 ifTrue: [ url := 'http://ss3.gemstone.com/ss/' ].
	
	projectName := UIManager default request: 'Enter a project name'.
	(projectName isNil or: [ projectName isEmpty ]) ifTrue: [ ^ self ].
	
	loadLastVersion := UIManager default confirm: 'Load last version?'.
		
	configurationName := self configurationNameForProject: projectName.
	[(Gofer new)
		url: url, projectName;
		package: configurationName;
		load.] on: Error do: [ :ex | 
			configurationName := self configurationNameForProject: (projectName first asString, (projectName allButFirst asLowercase)).
			[(Gofer new)
				url: url, projectName;
				package: configurationName;
				load.] on: Error do: [ :ex2 | self inform: 'Cannot find the repository or the configuration. Please check'. ^ self ].].
		
	loadLastVersion ifTrue: [
		(Smalltalk at: configurationName asSymbol) project lastVersion load
	].! !

!MBLoadProjectCommand methodsFor: 'accessing' stamp: 'AlexandreBergel 8/10/2011 17:03'!
normalizeProjectName: squeaksourceProject
	^ squeaksourceProject first asUppercase asString, squeaksourceProject allButFirst
! !

!MBLoadProjectCommand methodsFor: 'accessing' stamp: 'AlexandreBergel 5/18/2011 19:05'!
title
	^ 'load project'! !

MBDevCycleCommands subclass: #MBReleaseDevelopmentVersionCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBReleaseDevelopmentVersionCommand methodsFor: 'documentation' stamp: 'fds 2/26/2011 21:46'!
documentation
	^ 'release development version'! !

!MBReleaseDevelopmentVersionCommand methodsFor: 'execute' stamp: 'dkh 4/7/2011 21:23'!
execute
	"Turn the version into a release. It therefore appears as #stable afterward"

	| message newVersion |
	message := MBPlatform current multilineRequest: 'Enter commit message' initialAnswer: ''.
	message == nil
		ifTrue: [ ^ self ].
	self checkUserInRepositoryOfPackage: self configurationClass name asString.
	MetacelloToolBox
		saveModifiedDevelopmentPackages: #development
		for: self configurationClass name asString
		description: message.
	MBToolBox
		updateDevelopment: #development
		for: self configurationClass name asString
		updateProjects: false
		description: message.
	newVersion := (target project version: #development) versionNumber copy incrementMinorVersionNumber.
	MetacelloToolBox releaseDevelopmentVersionIn: self configurationClass description: message.
! !

!MBReleaseDevelopmentVersionCommand methodsFor: 'ordering' stamp: 'dkh 4/7/2011 22:20'!
order

	^'60'! !

!MBReleaseDevelopmentVersionCommand methodsFor: 'accessing' stamp: 'dkh 4/7/2011 21:59'!
title
	^ 'release dev'! !

MBDevCycleCommands subclass: #MBUpdateDevCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBUpdateDevCommand methodsFor: 'documentation' stamp: 'dkh 3/22/2011 19:12'!
documentation
	^ 'Update to the latest #development version''s repository.'! !

!MBUpdateDevCommand methodsFor: 'execute' stamp: 'dkh 4/6/2011 20:54'!
execute

	| version modifiedPkgs modifiedPkgDirectives choices index wc loadBlock fetchingLoader |
	self configurationClass project updateProject.
	modifiedPkgDirectives := OrderedCollection new.
	version := self configurationClass project version: #development.
	loadBlock := [ (self configurationClass project version: #development) load: version defaultPackageNamesToLoad ].
	version packages detect: [ :each | (wc := each workingCopy) notNil and: [ wc modified ] ] ifNone: [ ^ loadBlock value ].
	(fetchingLoader := version fetch: version defaultPackageNamesToLoad) loadDirective
		packageDirectivesDo: [ :pkgDirective | 
			((wc := pkgDirective spec workingCopy) notNil and: [ wc modified ])
				ifTrue: [ modifiedPkgDirectives add: pkgDirective ] ].
	modifiedPkgDirectives isEmpty
		ifTrue: [ ^ fetchingLoader doLoad ].
	^ self updateDevelopmentChoice: modifiedPkgDirectives mergeBlock: loadBlock loadBlock: [ fetchingLoader doLoad ]! !

!MBUpdateDevCommand methodsFor: 'ordering' stamp: 'dkh 4/7/2011 22:21'!
order

	^'40'! !

!MBUpdateDevCommand methodsFor: 'accessing' stamp: 'dkh 3/22/2011 19:11'!
title
	^ 'update dev'! !

!MBUpdateDevCommand methodsFor: 'execute' stamp: 'dkh 4/6/2011 20:51'!
updateDevelopmentChoice: modifiedPkgDirectives mergeBlock: mergeBlock loadBlock: loadBlock

	| version choices index |
	version := self configurationClass project version: #development.
	choices := #(
		'Proceed and load over modified packages' 
		'Proceed and allow me to perform a merge on the modified packages' 
		'Abort the load and provide me with a list of the packages requiring a merge' 
		'Abort the load and I''ll take care of things myself').
	index := MBPlatform current
		chooseFrom: choices
		message:
			'There are new versions of modified packages involved in this update. Please choose the action you''d like to take:'.
	(#(0 4) includes: index) ifTrue: [ ^ self ].
	index = 1
		ifTrue: [ 
			^ loadBlock
				on: Warning
				do: [ :ex | ex resume ] ].
	index = 2
		ifTrue: [ 
			modifiedPkgDirectives do: [ :pkgDirective | pkgDirective externalReference version merge ].
			^ mergeBlock value ].
	index = 3
		ifTrue: [ 
			| strm |
			strm := WriteStream on: String new.
			modifiedPkgDirectives
				do: [ :pkgDirective | 
					strm
						nextPutAll: pkgDirective file;
						cr ].
			^ self request: 'List of modified packages to be loaded' initialAnswer: strm contents ]! !

MBCommand subclass: #MBInfoCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

MBInfoCommand subclass: #MBOpenRepositoryCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBOpenRepositoryCommand methodsFor: 'documentation' stamp: 'fds 2/27/2011 10:42'!
documentation
	^ 'Open an inspector on the remote repository.'! !

!MBOpenRepositoryCommand methodsFor: 'execute' stamp: 'dkh 3/4/2011 14:31'!
execute
	| repo |
	(repo := self repository) ifNotNil: [
		MBPlatform current openRepository: repo] ! !

!MBOpenRepositoryCommand methodsFor: 'accessing' stamp: 'dkh 3/16/2011 06:04'!
repository
	"Return the repository of the configuration. Create one (using UI) if necessary"

	^self chooseRepositoryFromList: target repositories
! !

!MBOpenRepositoryCommand methodsFor: 'accessing' stamp: 'dkh 03/12/2011 02:36'!
title
	^ 'open repository'! !

MBCommand subclass: #MBVersionCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

MBVersionCommand subclass: #MBAddBaselineCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBAddBaselineCommand methodsFor: 'util' stamp: 'dkh 4/5/2011 20:44'!
addBaselineForConfiguration: aConfigurationClass repository: repository number: baselineNumberAsString packages: packageNames configurations: configurationNames
	"Define a new baseline on the selected configuration class"
	
	"repository is a Monticello repository
	 baselineNumberAsString could be 2.3.1 
	 packageNames is the list of packages used in the baseline
	configurationNames is the list of configuration names on which this baseline depends on
	"
	
	"PROBABLY THAT configurationNames IS NOT NECESSARY"
	"PROBABLY THIS METHOD HAS TO BE MOVED IN ABSTRACTVERSIONINFO"
	
	self checkUserInRepository: repository.
	
	MetacelloToolBox
	    createBaseline: baselineNumberAsString, '-baseline'
	    for: (MBToolBox baseNameOfConfiguration: aConfigurationClass)
	    repository: repository description
	    requiredProjects: (self basenamesOfConfigurations: 
								(configurationNames collect: [:cn | Smalltalk globals at: cn asSymbol]))
	    packages: packageNames
	    dependencies:
	      {}
	    groups:
	      {('default' -> packageNames)}! !

!MBAddBaselineCommand methodsFor: 'util' stamp: 'JuanPabloSandovalAlcocer 6/30/2012 20:21'!
askForABaselineIfCancel: aBlock  
	"Ask for a baseline number. Return a string as a result"

	| existingBaselines msg baselineNumber |
	existingBaselines := requestor baselines. 
	
	existingBaselines size > 0  
		ifTrue: [ msg := 'Current baselines:', 
							String cr, 
							(existingBaselines inject: '' into: [ :sum :el | sum, el name, String cr ]), 
							'Enter a new baseline number' ]
		ifFalse: [ msg := 'Enter a new baseline number ("-baseline" will be automatically added)' ].
		
	baselineNumber := MBPlatform current request: msg initialAnswer: '1.0'.
	baselineNumber ifNil: [ ^ aBlock value ].
	^ baselineNumber! !

!MBAddBaselineCommand methodsFor: 'util' stamp: 'dkh 4/7/2011 00:28'!
askForARepositoryIfCancel: aBlock
	"Ask the user for an appropriate http repository. Check if there is a user defined in it"
	
	| mcPackage workingCopy repositories repository repositoryIndex |
	mcPackage := MCPackage named: (self configurationClass name).
	workingCopy := mcPackage workingCopy.
	repositories := workingCopy repositoryGroup repositories.
	repositories := repositories reject: [ :rep | rep = MCCacheRepository default ].
	
	repositories ifEmpty: [ 
		| projectName answer squeakSourceURL |
		projectName := MBToolBox baseNameOf: target configurationClass name.
		squeakSourceURL := 'http://www.squeaksource.com/', projectName.
		answer := MBPlatform current confirm: 'You need to say where your project will be saved.
No HTTP repository associated. Do you want to add ', squeakSourceURL.
		answer ifFalse: [ MBPlatform current inform: 'Add a http repository with Monticello browser'. ^ aBlock value ].
		target configurationRoot username: (MBPlatform current request: 'Squeaksource username (initial)').
		target configurationRoot password: (MBPlatform current request: 'Squeaksource password (in clear)').
	
		workingCopy repositoryGroup 
			addRepository: (repository := MCHttpRepository 
											location: squeakSourceURL user: self username password: self password).
		 ].
	
	(repositories size > 1) ifTrue: [
		repositoryIndex :=  MBPlatform current chooseFrom: (repositories collect: #printString).
		repositoryIndex = 0 ifTrue: [ ^ aBlock value ].
		repository := repositories at: repositoryIndex ].

	(repositories size = 1) ifTrue: [ 
		repository := repositories first ].
	self checkUserInRepository: repository.

	^ repository ! !

!MBAddBaselineCommand methodsFor: 'util' stamp: 'dkh 4/12/2011 11:17'!
askForPackagesNamesIfCancel: aBlock  
	"Let the user pick some packages names, which could also be configurations"
	
	| addedPackages addedConfigurations packagePattern package |
	addedPackages := OrderedCollection new.
	addedConfigurations := OrderedCollection new.
	packagePattern := MBPlatform current 
							request: 'Please enter a pattern to filter package names' initialAnswer: '*'.
	packagePattern ifNil: [ ^ aBlock value ].
	
	[ | packageNames workingCopies |
	 packageNames := OrderedCollection new.
	workingCopies := OrderedCollection new.
	self workingCopies do: [ :pkg | 
		((packagePattern match: pkg package name) and: [ (addedPackages includes: pkg package name) not ])
			ifTrue: [ 
				packageNames add: pkg package name.
				workingCopies add: pkg ] ].
	 package := 
		MBPlatform current 
			chooseFrom: packageNames
			values: workingCopies
			title: 'Add dependent package (cancel to stop)'.
	 package ifNotNil: [
		(package package name beginsWith: 'ConfigurationOf')
			ifTrue: [ addedConfigurations add: package package name ]
			ifFalse: [ addedPackages add: package package name ] ].
	package notNil ] whileTrue.

	(addedPackages isEmpty and: [ addedConfigurations isEmpty ])
		ifTrue: [ MBPlatform current inform: 'No package or configuration added. No baseline has been created'. ^ aBlock value].

	^ {addedPackages . addedConfigurations}! !

!MBAddBaselineCommand methodsFor: 'util' stamp: 'AlexandreBergel 3/26/2011 21:22'!
basenamesOfConfigurations: someConfigurations
	^ someConfigurations collect: [ :c | MBToolBox baseNameOfConfiguration: c  ]! !

!MBAddBaselineCommand methodsFor: 'documentation' stamp: 'fds 2/26/2011 19:37'!
documentation 
	^ 'Add a new baseline in the selected configuration'! !

!MBAddBaselineCommand methodsFor: 'execute' stamp: 'dkh 4/5/2011 20:43'!
execute
	| repository baselineNumber v addedPackages addedConfigurations |

	"0 -- selected a repository"
	repository := self askForARepositoryIfCancel: [ ^ self ].

	"1 -- Selecting baseline name"
	baselineNumber := self askForABaselineIfCancel: [ ^ self ].
	
	"2 -- add for package names"
	v := self askForPackagesNamesIfCancel: [ ^ self ].

	addedPackages := v first.
	addedConfigurations := v second.

	"3 -- Creating baseline"
	self addBaselineForConfiguration: self configurationClass repository: repository number: baselineNumber packages: addedPackages configurations: addedConfigurations

! !

!MBAddBaselineCommand methodsFor: 'accessing' stamp: 'fds 2/26/2011 10:51'!
title
	^ 'add baseline'! !

!MBAddBaselineCommand methodsFor: 'util' stamp: 'AlexandreBergel 3/26/2011 21:20'!
workingCopies
	^ MCWorkingCopy allManagers asSortedCollection: [ :a :b | a name <= b name]! !

MBVersionCommand subclass: #MBAddDescriptionCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBAddDescriptionCommand methodsFor: 'execute' stamp: 'dkh 4/7/2011 00:29'!
appendDescription: message to: versionString

	| toolbox |
	self checkUserInRepositoryOfPackage: self configurationClass name asString.

	toolbox := MetacelloToolBox configurationNamed: self configurationClass name asString.
	toolbox
		updateVersionMethodForVersion: versionString
		updateProjects: false
		updatePackages: false
		versionSpecsDo: [ :attribute :versionSpec | 
			attribute == #common
				ifTrue: [ 
					"update the author, description and timeStamp"
					versionSpec
						author: MetacelloPlatform current authorName;
						timestamp: MetacelloPlatform current timestamp.
					MetacelloToolBox appendDescription: message to: versionSpec ].
			true ].
	toolbox commitMethod
! !

!MBAddDescriptionCommand methodsFor: 'documentation' stamp: 'dkh 2/28/2011 08:34'!
documentation 
	^ 'Append description to the of the selected version'! !

!MBAddDescriptionCommand methodsFor: 'execute' stamp: 'dkh 3/4/2011 13:58'!
execute
	| message |
	message := MBPlatform current multilineRequest: 'Enter description' initialAnswer: ''.
	message == nil
		ifTrue: [ ^ self ].
	self appendDescription: message to: target version versionString.
! !

!MBAddDescriptionCommand methodsFor: 'accessing' stamp: 'dkh 2/28/2011 08:33'!
title
	^ 'add description'! !

MBVersionCommand subclass: #MBArchiveVersionCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBArchiveVersionCommand methodsFor: 'documentation' stamp: 'dkh 4/7/2011 15:35'!
documentation 
	^ 'Archive the selected version to a selected repository.'! !

!MBArchiveVersionCommand methodsFor: 'execute' stamp: 'dkh 4/7/2011 19:52'!
execute
	| version archiveRepository |
	version := target version.
	version ignoreImage: true.
	archiveRepository := self pickRepositoryFrom: self repositories message: 'Choose the archive repository'.
	(archiveRepository respondsTo: #flushCache)
		ifTrue: [ archiveRepository perform: #flushCache ].
	"Copy the source configuration to the archive repository"
	target configurationInfo project projectPackage
		copySpecTo: (archiveRepository asRepositorySpecFor: target configurationInfo project).
	"Fetch the rest of the packages and configurations"
	version cacheRepository: archiveRepository.
	version fetch: 'ALL'! !

!MBArchiveVersionCommand methodsFor: 'accessing' stamp: 'dkh 4/7/2011 15:35'!
title
	^ 'archive version'! !

MBVersionCommand subclass: #MBBrowseCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBBrowseCommand methodsFor: 'documentation' stamp: 'fds 2/26/2011 20:00'!
documentation
	^ 'Open a code browser on the version. Use this to manually adjust the Metacello declaration. Knowledge about Metacello is required.'! !

!MBBrowseCommand methodsFor: 'execute' stamp: 'dkh 3/5/2011 21:26'!
execute
	
	^MBPlatform current browseMethodForVersion: target version! !

!MBBrowseCommand methodsFor: 'accessing' stamp: 'fds 2/27/2011 11:04'!
title
	^ 'browse'! !

MBVersionCommand subclass: #MBCompareToCurrentVersionCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBCompareToCurrentVersionCommand methodsFor: 'documentation' stamp: 'dkh 2/28/2011 10:31'!
documentation
	^ 'Compare the selected version with the #stable version'! !

!MBCompareToCurrentVersionCommand methodsFor: 'execute' stamp: 'dkh 3/5/2011 20:35'!
execute
	| info cv |
	(info := target configurationInfo) ifNil: [ ^self ].
	(cv := info currentVersion) ifNil: [ ^self ].
	MBPlatform current edit: (MetacelloToolBox
		compareVersion:  cv versionString
		for: target configurationBasename 
		to: target version versionString) printString
! !

!MBCompareToCurrentVersionCommand methodsFor: 'accessing' stamp: 'dkh 2/28/2011 10:31'!
title
	^ 'compare to current'! !

MBVersionCommand subclass: #MBCompareToStableVersionCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBCompareToStableVersionCommand methodsFor: 'documentation' stamp: 'dkh 2/28/2011 10:32'!
documentation
	^ 'Compare the selected version with the #stable version'! !

!MBCompareToStableVersionCommand methodsFor: 'execute' stamp: 'dkh 3/5/2011 20:35'!
execute
	MBPlatform current edit: (MetacelloToolBox
		compareVersion:  #stable
		for: target configurationBasename 
		to: target version versionString) printString
! !

!MBCompareToStableVersionCommand methodsFor: 'accessing' stamp: 'fds 2/26/2011 21:42'!
title
	^ 'compare to stable'! !

MBVersionCommand subclass: #MBCopyBaselineCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBCopyBaselineCommand methodsFor: 'execute' stamp: 'dkh 3/19/2011 10:43'!
copyBaselineWithNumber: baselineNumberAsString
	"Copy myself into a new baseline, with a different number"

	| sourceCode newSource newNumber newSelector comment |
	self 
		assert: [ baselineNumberAsString ~= target versionString ] 
		description: 'Cannot assign the same baseline number than me to my copy'.
		
	self 
		assert: [ (baselineNumberAsString endsWith: 'baseline') not ] 
		description: 'The baseline number cannot end with "-baseline". It will be automatically added.'.

	comment := MBPlatform current request: 'Enter a comment for the new baseline'.
	MetacelloToolBox 
		createBaseline: baselineNumberAsString, '-baseline' 
		for: target configurationBasename 
		from: target versionString 
		description: comment.! !

!MBCopyBaselineCommand methodsFor: 'documentation' stamp: 'fds 2/26/2011 19:48'!
documentation
	^ 'Copy the selected baseline under a new name'! !

!MBCopyBaselineCommand methodsFor: 'execute' stamp: 'dkh 3/4/2011 12:27'!
execute

	| answer |
	answer := MBPlatform current request: 'give a new baseline number (the prefix "-baseline" will be added)'.
	answer ifNil: [ ^ self ].

	self copyBaselineWithNumber: answer

! !

!MBCopyBaselineCommand methodsFor: 'accessing' stamp: 'dkh 3/20/2011 16:16'!
title
	^ 'copy baseline'! !

MBVersionCommand subclass: #MBLoadCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBLoadCommand methodsFor: 'documentation' stamp: 'fds 2/26/2011 20:09'!
documentation
	^ 'Load into your image the selected version or baseline. If you already have a version installed, then it will be simply overriden.' ! !

!MBLoadCommand methodsFor: 'execute' stamp: 'dkh 3/4/2011 14:02'!
execute
	| answer |
	answer := MBPlatform current confirm: 'Are you sure you want to load ', target name.
	answer ifTrue: 
		[ target version load: target version defaultPackageNamesToLoad ]! !

!MBLoadCommand methodsFor: 'accessing' stamp: 'dkh 3/20/2011 16:15'!
title
	^ 'load version'! !

MBVersionCommand subclass: #MBOpenForDevelopmentCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBOpenForDevelopmentCommand methodsFor: 'documentation' stamp: 'dkh 4/11/2011 16:57'!
documentation
	^ 'Load into your image the selected version. If you already have a version installed, then it will be simply overriden. Update the #development symbolic version to be this version' ! !

!MBOpenForDevelopmentCommand methodsFor: 'execute' stamp: 'dkh 4/11/2011 16:59'!
execute
	| answer |
	answer := MBPlatform current confirm: 'Are you sure you want to load ' , target name.
	answer
		ifTrue: [ 
			target version load: target version defaultPackageNamesToLoad.
			MetacelloToolBox
				modifySymbolicVersion: #development
				for: self configurationClass name asString
				attribute: #common
				to: target version versionString ]! !

!MBOpenForDevelopmentCommand methodsFor: 'accessing' stamp: 'dkh 4/11/2011 16:56'!
title
	^ 'open for development'! !

MBVersionCommand subclass: #MBRemoveCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBRemoveCommand methodsFor: 'documentation' stamp: 'fds 2/26/2011 19:57'!
documentation
	^ 'Remove from the configuration the selected version or baseline'! !

!MBRemoveCommand methodsFor: 'execute' stamp: 'dkh 3/19/2011 14:46'!
execute
	"Remove from the configuration class what is selected in the right panel list"

	| answer imported |
	imported := Set new.
	self configurationClass project versions do: [ :version | imported addAll: version importedVersions ].
	(imported includes: target versionString)
		ifTrue: [ 
			^ self
				inform:
					'The version ' , target printString
						, ' is imported by another version. You must remove the import reference before you can remove this version.' ].
	answer := MBPlatform current
		confirm: 'Are you sure you want to remove ' , target printString , ' from ' , self configurationClass name , '?'.
	answer
		ifTrue: [ 
			| cm |
			self configurationClass project symbolicVersionSymbols
				do: [ :symbolicVersion | 
					(MetacelloToolBox configurationNamed: self configurationClass name asString)
						modifySymbolicVersionMethodFor: symbolicVersion
							symbolicVersionSpecsDo: [ :symbolicVersionSpec | 
									symbolicVersionSpec versionString = target versionString
										ifTrue: [ symbolicVersionSpec versionString: #notDefined ].
									true ];
						commitMethod ].
			cm := MBToolBox compiledMethodForVersion: target version.
			cm methodClass removeSelector: cm selector ]! !

!MBRemoveCommand methodsFor: 'accessing' stamp: 'dkh 3/20/2011 16:16'!
title
	^ 'remove version'! !

MBVersionCommand subclass: #MBSaveAllPackagesAndAddVersionCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBSaveAllPackagesAndAddVersionCommand methodsFor: 'documentation' stamp: 'fds 2/26/2011 19:37'!
documentation 
	^ 'Add a new version in the selected configuration'! !

!MBSaveAllPackagesAndAddVersionCommand methodsFor: 'execute' stamp: 'JuanPabloSandovalAlcocer 7/11/2012 13:50'!
execute
	| message newVersionTarget |

	"Fix the configuration if something is wrong"
	(self configurationClass methodDict includesKey: #development:)
		ifFalse: [ self inform: 'The configuration is not properly defined (symbolic information is missing). Please fix this manually.'. ^ self  ].
	
	[(target project version: #development)] on: Error do: [ :ex | 
		self inform: 'The configuration is oddly defined. The symbolic tag #development does not correspond to an existing version. Please, fix this manually.'.
		^ self 
	].
	
	
	message := MBPlatform current
		multilineRequest:
			'Projec: ',  self projectName , ': you are about to save all modifed packages and the configuration'
				, (target project version: #development) versionString
		initialAnswer: (target project version: #development) versionString, ' :'.
		
	(message isNil or: [ message isEmpty ])
		ifTrue: [ self inform: 'No message, the saving is aborted'. ^ self ].	

	(MBCheckpointDevCommand target: target configurationInfo for: requestor) executeWithMessage: message.
	(MBAddDevelopmentVersionCommand target: target for: requestor) execute.
	
  	newVersionTarget := target configurationInfo versions first.
	(MBSetDescriptionCommand target: newVersionTarget for: requestor) executeWithMessage: message.
	
	(MBSaveConfigurationCommand target: target configurationInfo for: requestor) executeWithMessage: message.
! !

!MBSaveAllPackagesAndAddVersionCommand methodsFor: 'accessing' stamp: 'AlexandreBergel 3/1/2011 17:03'!
title
	^ 'save all and add development version'! !

MBVersionCommand subclass: #MBSetCurrentVersionCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBSetCurrentVersionCommand methodsFor: 'documentation' stamp: 'dkh 4/3/2011 17:36'!
documentation
	^ '***Experimental*** Override calculated currentVersion with the selected version.'! !

!MBSetCurrentVersionCommand methodsFor: 'execute' stamp: 'dkh 4/3/2011 17:24'!
execute
	target configurationInfo currentVersion: target version! !

!MBSetCurrentVersionCommand methodsFor: 'accessing' stamp: 'dkh 4/3/2011 17:10'!
title
	^ 'set version as current'! !

MBVersionCommand subclass: #MBSetDescriptionCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBSetDescriptionCommand methodsFor: 'documentation' stamp: 'fds 2/26/2011 21:49'!
documentation
	^ 'Set the description on the selected development version'! !

!MBSetDescriptionCommand methodsFor: 'execute' stamp: 'AlexandreBergel 4/15/2011 10:29'!
execute
	| toolbox updatedSpecs message |
	message := MBPlatform current multilineRequest: 'Enter description' initialAnswer: ''.
	(message isNil or: [ message isEmpty ])
		ifTrue: [ ^ self ].
	self executeWithMessage: message! !

!MBSetDescriptionCommand methodsFor: 'execute' stamp: 'AlexandreBergel 4/15/2011 10:29'!
executeWithMessage: message
	| toolbox updatedSpecs |
	toolbox := MetacelloToolBox configurationNamed: target configurationBasename.
	toolbox
		updateVersionMethodForVersion: target version versionString
		updateProjects: false
		updatePackages: false
		versionSpecsDo: [ :attribute :versionSpec | 
			attribute == #common
				ifTrue: [ 
					"update the author, description and timeStamp"
					versionSpec
						author: MetacelloPlatform current authorName;
						timestamp: MetacelloPlatform current timestamp.
					MetacelloToolBox appendDescription: message to: versionSpec ].
			true ].
	toolbox commitMethod
! !

!MBSetDescriptionCommand methodsFor: 'accessing' stamp: 'dkh 3/2/2011 19:55'!
title
	^ 'set description'! !

MBVersionCommand subclass: #MBUpdatePackageCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBUpdatePackageCommand methodsFor: 'documentation' stamp: 'fds 2/26/2011 21:48'!
documentation
	^ 'Update the current version with the last Monticello package versions '! !

!MBUpdatePackageCommand methodsFor: 'execute' stamp: 'fds 2/26/2011 21:52'!
execute

	MetacelloToolBox
		updateDevelopment: target version versionString
		for: target configurationBasename
		updateProjects: false
		description: ''! !

!MBUpdatePackageCommand methodsFor: 'accessing' stamp: 'dkh 2/28/2011 12:57'!
title
	^ 'update packages'! !

MBVersionCommand subclass: #MBUpdateProjectCommand
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Commands'!

!MBUpdateProjectCommand methodsFor: 'documentation' stamp: 'dkh 4/10/2011 12:36'!
documentation
	^ 'Update the current version with the last project versions '! !

!MBUpdateProjectCommand methodsFor: 'execute' stamp: 'dkh 4/10/2011 12:39'!
execute

	MetacelloToolBox
		updateDevelopment: target version versionString
		for: target configurationBasename
		updatePackages: false
		description: ''! !

!MBUpdateProjectCommand methodsFor: 'accessing' stamp: 'dkh 4/10/2011 12:36'!
title
	^ 'update projects'! !
